@@ -1,13 +1,18 @@
 from typing import List
 
 from redash_python.services import (
+    AlertsService,
     BaseService,
     DashboardsService,
     DataSourcesService,
+    DestService,
+    GroupsService,
+    QSnipsService,
     QueriesService,
+    UsersService,
 )
 
-version = "0.0.17"
+version = "0.1.1"
 
 
 class Redash:
@@ -33,10 +38,15 @@ class Redash:
         self.dashboards = DashboardsService(self.__base)
         self.queries = QueriesService(self.__base)
         self.data_sources = DataSourcesService(self.__base)
+        self.alerts = AlertsService(self.__base)
+        self.destinations = DestService(self.__base)
+        self.users = UsersService(self.__base)
+        self.groups = GroupsService(self.__base)
+        self.query_snippets = QSnipsService(self.__base)
 
         # keep track of services
         attr_dict = self.__dict__
-        ignore_list = ["_Redash__base", "__base"]
+        ignore_list = ["_Redash__base", "__base", "version"]
         self.services = [
             attr_dict[k].__class__.__name__
             for k in self.__dict__
