@@ -3,6 +3,8 @@ from .base import BaseObject, BaseService
 from .dashboards import DashboardsService
 from .data_sources import DataSourcesService
 from .destinations import DestService
+from .groups import GroupsService
 from .mixins import *
 from .queries import QueriesService
+from .query_snippets import QSnipsService
 from .users import UsersService
